svn commit: samba r19577 - in branches: SAMBA_3_0/source/libsmb SAMBA_3_0_23/source/libsmb SAMBA_3_0_24/source/libsmb

jra at samba.org jra at samba.org
Mon Nov 6 19:21:45 GMT 2006


Author: jra
Date: 2006-11-06 19:21:44 +0000 (Mon, 06 Nov 2006)
New Revision: 19577

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=19577

Log:
Fix from Nils Nordman for bug #4085. Thanks !
Jeremy. 

Modified:
   branches/SAMBA_3_0/source/libsmb/passchange.c
   branches/SAMBA_3_0_23/source/libsmb/passchange.c
   branches/SAMBA_3_0_24/source/libsmb/passchange.c


Changeset:
Modified: branches/SAMBA_3_0/source/libsmb/passchange.c
===================================================================
--- branches/SAMBA_3_0/source/libsmb/passchange.c	2006-11-06 18:39:48 UTC (rev 19576)
+++ branches/SAMBA_3_0/source/libsmb/passchange.c	2006-11-06 19:21:44 UTC (rev 19577)
@@ -86,12 +86,13 @@
 
 	if (!NT_STATUS_IS_OK(result)) {
 
 		/* Password must change is the only valid error condition here
 		 * from where we can proceed, the rest like account locked out
 		 * or logon failure will lead to errors later anyway */
 
-		if (!NT_STATUS_EQUAL(result,
-				     NT_STATUS_PASSWORD_MUST_CHANGE)) {
+		if (!NT_STATUS_EQUAL(result, NT_STATUS_PASSWORD_MUST_CHANGE) &&
+		    !NT_STATUS_EQUAL(result, NT_STATUS_PASSWORD_EXPIRED)) {
 			slprintf(err_str, err_str_len-1, "Could not "
 				 "connect to machine %s: %s\n",
 				 remote_machine, cli_errstr(cli));
@@ -86,12 +86,13 @@
 	if (!NT_STATUS_IS_OK(result)) {
 
-		/* Password must change is the only valid error condition here
-		 * from where we can proceed, the rest like account locked out
-		 * or logon failure will lead to errors later anyway */
+		/* Password must change or Password expired are the only valid
+		 * error conditions here from where we can proceed, the rest like
+		 * account locked out or logon failure will lead to errors later
+		 * anyway */
 

Modified: branches/SAMBA_3_0_23/source/libsmb/passchange.c
===================================================================
--- branches/SAMBA_3_0_23/source/libsmb/passchange.c	2006-11-06 18:39:48 UTC (rev 19576)
+++ branches/SAMBA_3_0_23/source/libsmb/passchange.c	2006-11-06 19:21:44 UTC (rev 19577)
@@ -80,13 +80,14 @@
 
 		if (!NT_STATUS_IS_OK(result)) {
 
 			/* Password must change is the only valid error
 			 * condition here from where we can proceed, the rest
 			 * like account locked out or logon failure will lead
 			 * to errors later anyway */
 
-			if (!NT_STATUS_EQUAL(result,
-					     NT_STATUS_PASSWORD_MUST_CHANGE)) {
+			if (!NT_STATUS_EQUAL(result, NT_STATUS_PASSWORD_MUST_CHANGE) &&
+			    !NT_STATUS_EQUAL(result, NT_STATUS_PASSWORD_EXPIRED)) {
+
 				slprintf(err_str, err_str_len-1, "Could not "
 					 "connect to machine %s: %s\n",
 					 remote_machine, cli_errstr(&cli));
@@ -80,13 +80,14 @@
 		if (!NT_STATUS_IS_OK(result)) {
 
-			/* Password must change is the only valid error
-			 * condition here from where we can proceed, the rest
-			 * like account locked out or logon failure will lead
-			 * to errors later anyway */
+			/* Password must change or Password expired are the only valid
+			 * error conditions here from where we can proceed, the rest like
+			 * account locked out or logon failure will lead to errors later
+			 * anyway */
 

Modified: branches/SAMBA_3_0_24/source/libsmb/passchange.c
===================================================================
--- branches/SAMBA_3_0_24/source/libsmb/passchange.c	2006-11-06 18:39:48 UTC (rev 19576)
+++ branches/SAMBA_3_0_24/source/libsmb/passchange.c	2006-11-06 19:21:44 UTC (rev 19577)
@@ -80,13 +80,14 @@
 
 		if (!NT_STATUS_IS_OK(result)) {
 
 			/* Password must change is the only valid error
 			 * condition here from where we can proceed, the rest
 			 * like account locked out or logon failure will lead
 			 * to errors later anyway */
 
-			if (!NT_STATUS_EQUAL(result,
-					     NT_STATUS_PASSWORD_MUST_CHANGE)) {
+			if (!NT_STATUS_EQUAL(result, NT_STATUS_PASSWORD_MUST_CHANGE) &&
+			    !NT_STATUS_EQUAL(result, NT_STATUS_PASSWORD_EXPIRED)) {
+
 				slprintf(err_str, err_str_len-1, "Could not "
 					 "connect to machine %s: %s\n",
 					 remote_machine, cli_errstr(&cli));
@@ -80,13 +80,14 @@
 		if (!NT_STATUS_IS_OK(result)) {
 
-			/* Password must change is the only valid error
-			 * condition here from where we can proceed, the rest
-			 * like account locked out or logon failure will lead
-			 * to errors later anyway */
+			/* Password must change or Password expired are the only valid
+			 * error conditions here from where we can proceed, the rest like
+			 * account locked out or logon failure will lead to errors later
+			 * anyway */
 



More information about the samba-cvs mailing list